@@ -250,7 +250,6 @@ module Aws
             'ARCZonalShift' => 'arc-zonal-shift',
             'AccessAnalyzer' => 'access-analyzer',
             'Account' => 'account',
-            'AlexaForBusiness' => 'a4b',
             'Amplify' => 'amplify',
             'AmplifyBackend' => 'amplifybackend',
             'AmplifyUIBuilder' => 'amplifyuibuilder',
@@ -265,11 +264,13 @@ module Aws
             'AppRunner' => 'apprunner',
             'AppStream' => 'appstream2',
             'AppSync' => 'appsync',
+            'AppTest' => 'apptest',
             'Appflow' => 'appflow',
             'ApplicationAutoScaling' => 'application-autoscaling',
             'ApplicationCostProfiler' => 'application-cost-profiler',
             'ApplicationDiscoveryService' => 'discovery',
             'ApplicationInsights' => 'applicationinsights',
+            'ApplicationSignals' => 'application-signals',
             'Artifact' => 'artifact',
             'Athena' => 'athena',
             'AuditManager' => 'auditmanager',
@@ -280,7 +281,6 @@ module Aws
             'BCMDataExports' => 'bcm-data-exports',
             'Backup' => 'backup',
             'BackupGateway' => 'backup-gateway',
-            'BackupStorage' => 'backupstorage',
             'Batch' => 'batch',
             'Bedrock' => 'bedrock',
             'BedrockAgent' => 'bedrock-agent',
@@ -318,12 +318,12 @@ module Aws
             'CodeBuild' => 'codebuild',
             'CodeCatalyst' => 'codecatalyst',
             'CodeCommit' => 'codecommit',
+            'CodeConnections' => 'codeconnections',
             'CodeDeploy' => 'codedeploy',
             'CodeGuruProfiler' => 'codeguru-profiler',
             'CodeGuruReviewer' => 'codeguru-reviewer',
             'CodeGuruSecurity' => 'codeguru-security',
             'CodePipeline' => 'codepipeline',
-            'CodeStar' => 'codestar',
             'CodeStarNotifications' => 'codestar-notifications',
             'CodeStarconnections' => 'codestar-connections',
             'CognitoIdentity' => 'cognito-identity',
@@ -339,6 +339,7 @@ module Aws
             'ConnectContactLens' => 'contact-lens',
             'ConnectParticipant' => 'participant.connect',
             'ConnectWisdomService' => 'wisdom',
+            'ControlCatalog' => 'controlcatalog',
             'ControlTower' => 'controltower',
             'CostExplorer' => 'ce',
             'CostOptimizationHub' => 'cost-optimization-hub',
@@ -351,11 +352,13 @@ module Aws
             'DataSync' => 'datasync',
             'DataZone' => 'datazone',
             'DatabaseMigrationService' => 'dms',
+            'Deadline' => 'deadline',
             'Detective' => 'api.detective',
             'DevOpsGuru' => 'devops-guru',
             'DeviceFarm' => 'devicefarm',
             'DirectConnect' => 'directconnect',
             'DirectoryService' => 'ds',
+            'DirectoryServiceData' => 'ds-data',
             'DocDB' => 'rds',
             'DocDBElastic' => 'docdb-elastic',
             'Drs' => 'drs',
@@ -403,7 +406,6 @@ module Aws
             'GuardDuty' => 'guardduty',
             'Health' => 'health',
             'HealthLake' => 'healthlake',
-            'Honeycode' => 'honeycode',
             'IAM' => 'iam',
             'IVS' => 'ivs',
             'IVSRealTime' => 'ivsrealtime',
@@ -446,7 +448,6 @@ module Aws
             'KinesisVideoWebRTCStorage' => 'kinesisvideo',
             'LakeFormation' => 'lakeformation',
             'Lambda' => 'lambda',
-            'LambdaPreview' => 'lambda',
             'LaunchWizard' => 'launchwizard',
             'Lex' => 'runtime.lex',
             'LexModelBuildingService' => 'models.lex',
@@ -465,6 +466,7 @@ module Aws
             'MWAA' => 'airflow',
             'MachineLearning' => 'machinelearning',
             'Macie2' => 'macie2',
+            'MailManager' => 'mail-manager',
             'MainframeModernization' => 'm2',
             'ManagedBlockchain' => 'managedblockchain',
             'ManagedBlockchainQuery' => 'managedblockchain-query',
@@ -492,7 +494,6 @@ module Aws
             'MigrationHubOrchestrator' => 'migrationhub-orchestrator',
             'MigrationHubRefactorSpaces' => 'refactor-spaces',
             'MigrationHubStrategyRecommendations' => 'migrationhub-strategy',
-            'Mobile' => 'mobile',
             'Neptune' => 'rds',
             'NeptuneGraph' => 'neptune-graph',
             'Neptunedata' => 'neptune-db',
@@ -509,11 +510,13 @@ module Aws
             'OpsWorksCM' => 'opsworks-cm',
             'Organizations' => 'organizations',
             'Outposts' => 'outposts',
+            'PCS' => 'pcs',
             'PI' => 'pi',
             'Panorama' => 'panorama',
             'PaymentCryptography' => 'controlplane.payment-cryptography',
             'PaymentCryptographyData' => 'dataplane.payment-cryptography',
             'PcaConnectorAd' => 'pca-connector-ad',
+            'PcaConnectorScep' => 'pca-connector-scep',
             'Personalize' => 'personalize',
             'PersonalizeEvents' => 'personalize-events',
             'PersonalizeRuntime' => 'personalize-runtime',
@@ -527,6 +530,7 @@ module Aws
             'PrivateNetworks' => 'private-networks',
             'PrometheusService' => 'aps',
             'Proton' => 'proton',
+            'QApps' => 'data.qapps',
             'QBusiness' => 'qbusiness',
             'QConnect' => 'wisdom',
             'QLDB' => 'qldb',
@@ -549,6 +553,7 @@ module Aws
             'RolesAnywhere' => 'rolesanywhere',
             'Route53' => 'route53',
             'Route53Domains' => 'route53domains',
+            'Route53Profiles' => 'route53profiles',
             'Route53RecoveryCluster' => 'route53-recovery-cluster',
             'Route53RecoveryControlConfig' => 'route53-recovery-control-config',
             'Route53RecoveryReadiness' => 'route53-recovery-readiness',
@@ -564,6 +569,7 @@ module Aws
             'SSM' => 'ssm',
             'SSMContacts' => 'ssm-contacts',
             'SSMIncidents' => 'ssm-incidents',
+            'SSMQuickSetup' => 'ssm-quicksetup',
             'SSO' => 'portal.sso',
             'SSOAdmin' => 'sso',
             'SSOOIDC' => 'oidc',
@@ -598,6 +604,7 @@ module Aws
             'Support' => 'support',
             'SupportApp' => 'supportapp',
             'Synthetics' => 'synthetics',
+            'TaxSettings' => 'tax',
             'Textract' => 'textract',
             'TimestreamInfluxDB' => 'timestream-influxdb',
             'TimestreamQuery' => 'query.timestream',
@@ -616,7 +623,6 @@ module Aws
             'WAFV2' => 'wafv2',
             'WellArchitected' => 'wellarchitected',
             'WorkDocs' => 'workdocs',
-            'WorkLink' => 'worklink',
             'WorkMail' => 'workmail',
             'WorkMailMessageFlow' => 'workmailmessageflow',
             'WorkSpaces' => 'workspaces',
